"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.7.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.hyperscale_column_or_field import HyperscaleColumnOrField
globals()['HyperscaleColumnOrField'] = HyperscaleColumnOrField
from delphix.api.gateway.model.hyperscale_dataset_table_or_file import HyperscaleDatasetTableOrFile


class TestHyperscaleDatasetTableOrFile(unittest.TestCase):
    """HyperscaleDatasetTableOrFile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHyperscaleDatasetTableOrFile(self):
        """Test HyperscaleDatasetTableOrFile"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HyperscaleDatasetTableOrFile()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
